@@ -32,6 +32,7 @@
 
 #include <gtkmm/icontheme.h>
 
+#include "core/log-stream.h"
 #include "gcs-about-window.h"
 #include "gcs-i18n.h"
 
@@ -87,19 +88,28 @@ namespace gcs
             Glib::ustring translation_credits = _("translator-credits");
             set_translator_credits(translation_credits);
 
-            Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default();
             const Glib::ustring icon_name = "agave-icon";
-            // FIXME: Unix path separators
+            Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default();
+
             if (theme->has_icon(icon_name))
             {
-                m_logo = theme->load_icon(icon_name, m_logoSize,
-                        Gtk::ICON_LOOKUP_USE_BUILTIN);
-                set_logo(m_logo);
+                try
+                {
+                    m_logo = theme->load_icon(icon_name, m_logoSize,
+                            Gtk::ICON_LOOKUP_USE_BUILTIN);
+                    set_logo(m_logo);
+                }
+                catch (const Glib::Error& e)
+                {
+                    Glib::ustring message = "Couldn't load Agave logo image from theme. " + e.what();
+                    g_warning(message.c_str());
+                }
             }
         }
 
 
-        void AboutWindow::on_link_clicked(Gtk::AboutDialog& dialog,
+        void
+        AboutWindow::on_link_clicked(Gtk::AboutDialog& dialog,
                 const Glib::ustring& link)
         {
 #ifdef HAVE_GNOME
@@ -107,5 +117,16 @@ namespace gcs
 #endif // HAVE_GNOME
         }
 
+        void
+        AboutWindow::on_response(int response_id)
+        {
+            if (response_id == Gtk::RESPONSE_DELETE_EVENT ||
+                    response_id == Gtk::RESPONSE_CANCEL ||
+                    response_id == Gtk::RESPONSE_CLOSE)
+            {
+                hide();
+            }
+        }
+
     } // namespace Dialogs
 } // namespace gcs
