@@ -1,8 +1,6 @@
 /*******************************************************************************
- *  PROJECT: GNOME Colorscheme
- *
+ *  PROJECT: Agave
  *  AUTHOR: Jonathon Jongsma
- *
  *  Copyright (c) 2005 Jonathon Jongsma
  *
  *  License:
@@ -26,7 +24,6 @@
 #include "config.h"
 #include <cstdlib>  // for srand(), rand()
 #include <ctime>    // for time()
-#include <cassert>  // for assert() macro
 
 #include <boost/shared_ptr.hpp>
 
@@ -59,9 +56,6 @@
 namespace gcs
 {
     MainWindow* MainWindow::m_instance = NULL;
-    const gint MainWindow::WINDOW_HEIGHT = 400;
-    const gint MainWindow::WINDOW_WIDTH = 650;
-    const gint MainWindow::FAVORITES_WIDTH = 130;
 
     MainWindow& MainWindow::Instance(void)
     {
@@ -71,156 +65,112 @@ namespace gcs
         }
         else
         {
-            m_instance = new MainWindow();
+            Glib::RefPtr<Glade::Xml> glade = Glade::Xml::create(AGAVE_UIDIR
+                    "/agave.glade");
+            glade->get_widget_derived("AgaveWindow", m_instance);
             return *m_instance;
         }
     }
 
 
-    MainWindow::MainWindow(void) :
-        m_pLayout(Gtk::manage(new Gtk::VBox())),
-        m_pInnerLayout(Gtk::manage(new Gtk::HBox())),
-        m_pSchemeColumn(Gtk::manage(new Gtk::VBox())),
-        m_pScrollBox(Gtk::manage(new Gtk::ScrolledWindow())),
-        m_pBookmarkColumn(Gtk::manage(new Gtk::VBox())),
-        m_pPane(Gtk::manage(new Gtk::HPaned())),
-        m_pControls(Gtk::manage(new Gtk::HBox())),
-        m_pMainMenu(NULL),  // will be assigned in the constructor
-        m_pTweakBar(NULL),
-        m_pBookmarkBar(NULL),
-        m_pColorButton(NULL), 
-        m_pSchemeSelector(NULL),
-        m_pSchemeBox(Gtk::manage(new Widgets::SchemeBox())),
-        m_pBookmarkList(NULL),
-        m_PaletteView(Gtk::manage(new Widgets::PaletteView(
-                        Glib::build_filename(AGAVE_PALETTEDIR, "Web.gpl")))),
-        m_bookmarks_file(Conf::FAVORITES_FILE),
-        m_pStatusbar(Gtk::manage(new Gtk::Statusbar())),
+    MainWindow::MainWindow(GtkWindow *cobject, Glib::RefPtr<Glade::Xml>& refGlade) :
+        Gtk::Window(cobject),
+        m_glade(refGlade),
+        m_vbox_layout(NULL),
+        m_vbox_menu_toolbar(NULL),
+        m_vbox_main(NULL),
+        m_vbox_favorites(NULL),
+        m_vbox_scheme_display(NULL),
+        m_pane(NULL),
+        m_main_menu(NULL),
+        m_toolbar(NULL),
+        m_bookmark_bar(NULL),
+        m_color_button(NULL), 
+        m_scheme_selector(NULL),
+        m_scheme_box(Gtk::manage(new Widgets::SchemeBox())),
+        m_bookmark_list(Gtk::manage(new Widgets::BookmarkList())),
+        m_palette_view(NULL),
         m_pAbout(new Dialogs::AboutWindow()),
         m_pHistory(new HistoryNavigation<tHexString>())
     {
-        // migrate the old settings if it hasn't been done yet
-        Conf::migrate_old_config_directory();
-
-        m_pBookmarkList = Gtk::manage(new Widgets::BookmarkList(m_bookmarks_file));
-        init_actions();
-        init_ui();
-
         // seed the random number generator for generating random color schemes
         srand(time(NULL));
 
+        // migrate the old settings if it hasn't been done yet
+        Conf::migrate_old_config_directory();
+
+        // make sure the glade file has been loaded
+        g_assert(m_glade);
+
+        init_actions();
+        init_ui();  // load menus, cache glade widgets
 
         /* The menu bar across the top of the window */
-        m_pMainMenu = static_cast<Gtk::Menu *>(
-                m_refUIManager->get_widget("/MainMenu"));
-        assert(m_pLayout);
-        assert(m_pMainMenu);
-        m_pLayout->pack_start(*m_pMainMenu, Gtk::PACK_SHRINK);
+        m_vbox_menu_toolbar->pack_start(*m_main_menu, Gtk::PACK_SHRINK);
         LOG("Added main menu");
 
-        m_pTweakBar = static_cast<Gtk::Toolbar *>(
-                m_refUIManager->get_widget("/TweakBar"));
-        assert(m_pTweakBar);
-        m_pTweakBar->set_toolbar_style(Gtk::TOOLBAR_BOTH_HORIZ);
-        m_pLayout->pack_start(*m_pTweakBar, Gtk::PACK_SHRINK, 0);
+        m_toolbar->set_toolbar_style(Gtk::TOOLBAR_BOTH_HORIZ);
+        m_vbox_menu_toolbar->pack_start(*m_toolbar, Gtk::PACK_SHRINK, 0);
 
-        assert(m_pPane);
-        m_pLayout->pack_start(*m_pPane);
-
-        assert(m_pInnerLayout);
-        assert(m_pSchemeColumn);
-        m_pInnerLayout->pack_start(*m_pSchemeColumn);
-
-        assert(m_pPane);
-        m_pPane->pack1(*m_pInnerLayout);
-
-        assert(m_pBookmarkColumn);
-        m_pPane->pack2(*m_pBookmarkColumn, Gtk::SHRINK);
-
-        // Set up the SchemeBox
-        assert(m_pSchemeBox);
-        Gtk::Menu * pSwatchPopup = static_cast<Gtk::Menu *>(
-                m_refUIManager->get_widget("/ColorSwatchPopup"));
-        LOG("popup widget: " << (long) pSwatchPopup);
-        m_pSchemeColumn->pack_start(*m_pSchemeBox, Gtk::PACK_EXPAND_WIDGET, 0);
-        m_pSchemeBox->signal_color_selected().connect(
-                sigc::mem_fun(*this, &MainWindow::on_schemebox_color_selected));
-
-        // set up the main controls
-        assert(m_pControls);
-        m_pSchemeColumn->pack_start(*m_pControls, Gtk::PACK_SHRINK);
-        LOG("Added Controls box");
-
-        m_pColorButton = Gtk::manage(new Gtk::ColorButton);
-        assert(m_pColorButton);
-        m_pColorButton->signal_color_set().connect(sigc::mem_fun(*this,
+        m_color_button->signal_color_set().connect(sigc::mem_fun(*this,
                     &MainWindow::on_color_changed));
-        LOG("created Color Button");
-        m_pSchemeSelector = Gtk::manage(new Widgets::SchemeSelector);
-        assert(m_pSchemeSelector);
-        m_pSchemeSelector->signal_changed().connect(sigc::mem_fun(*this,
+
+        m_scheme_selector->signal_changed().connect(sigc::mem_fun(*this,
                     &MainWindow::on_schemetype_changed));
         LOG("Created Scheme Selector");
-        m_pControls->pack_start(*m_pColorButton, Gtk::PACK_SHRINK);
-        m_pControls->pack_start(*m_pSchemeSelector, Gtk::PACK_EXPAND_WIDGET);
-        m_pControls->set_spacing(Conf::UI_SPACING_SMALL);
-        m_pControls->set_border_width(Conf::UI_SPACING_SMALL);
-
-        assert(m_PaletteView);
-        m_pSchemeColumn->pack_start(*m_PaletteView, Gtk::PACK_SHRINK, 0);
-        m_PaletteView->set_border_width(Conf::UI_SPACING_SMALL);
-        m_PaletteView->signal_color_selected().connect(
-            sigc::mem_fun(*this, &MainWindow::on_schemebox_color_selected));
-        m_PaletteView->set_expanded();
-
-
-        assert(m_pBookmarkList);
-        m_pBookmarkList->set_size_request(FAVORITES_WIDTH, NO_SIZE_REQUEST);
-        m_pScrollBox->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
-        m_pBookmarkColumn->pack_start(*m_pScrollBox);
-        m_pScrollBox->add(*m_pBookmarkList);
-        m_pBookmarkList->get_selection()->signal_changed().connect(
-                sigc::mem_fun(*this, &MainWindow::on_bookmarks_selection_changed));
-        
-        m_pBookmarkBar = dynamic_cast<Gtk::Toolbar *>(m_refUIManager->get_widget("/BookmarkBar"));
-        assert(m_pBookmarkBar);
-        m_pBookmarkColumn->pack_start(*m_pBookmarkBar, Gtk::PACK_SHRINK);
-        m_pBookmarkBar->set_toolbar_style(Gtk::TOOLBAR_BOTH_HORIZ);
-
-        assert(m_pStatusbar);
-        m_pStatusbar->push(_("Choose a Color and a Scheme Type"), 1);
-        m_pLayout->pack_start(*m_pStatusbar, Gtk::PACK_SHRINK);
-
-        assert(m_pAbout);
-
-        add(*m_pLayout);
-        m_pLayout->show_all();
-        set_position(Gtk::WIN_POS_CENTER);
-
-        //Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default();
-        //theme->append_search_path(DATADIR "/icons");
-
-        // need to use a GTK+ function since it's not available in gtkmm yet
-        gtk_window_set_default_icon_name("agave-icon");
-
-        set_default_size(Conf::get_window_width(), Conf::get_window_height());
-        set_title(PACKAGE_NAME);
 
+        // Set up the SchemeBox
+        g_assert(m_scheme_box);
+        m_vbox_scheme_display->pack_start(*m_scheme_box, Gtk::PACK_EXPAND_WIDGET, 0);
+        m_scheme_box->signal_color_selected().connect(
+                sigc::mem_fun(*this, &MainWindow::on_schemebox_color_selected));
         std::list<Gtk::TargetEntry> listTargets;
         listTargets.push_back(Gtk::TargetEntry("application/x-color"));
-        m_pSchemeBox->drag_dest_set(listTargets);
-        m_pSchemeBox->signal_drag_data_received().connect(sigc::mem_fun(*this,
+        m_scheme_box->drag_dest_set(listTargets);
+        m_scheme_box->signal_drag_data_received().connect(sigc::mem_fun(*this,
                     &MainWindow::on_drop_drag_data_received));
+
+        m_palette_view->signal_color_selected().connect(
+            sigc::mem_fun(*this, &MainWindow::on_schemebox_color_selected));
+        m_palette_view->set_from_file(Glib::build_filename(AGAVE_PALETTEDIR, "Web.gpl"));
+        m_palette_view->set_expanded(Conf::get_palette_expanded());
+
+        m_bookmark_list->get_selection()->signal_changed().connect(
+                sigc::mem_fun(*this, &MainWindow::on_bookmarks_selection_changed));
+        
+        m_scrolledwindow_favorites->add(*m_bookmark_list);
+        m_vbox_favorites->pack_start(*m_bookmark_bar, Gtk::PACK_SHRINK);
+        m_bookmark_bar->set_toolbar_style(Gtk::TOOLBAR_BOTH_HORIZ);
+
+        m_statusbar->push(_("Choose a Color and a Scheme Type"), 1);
+
+        g_assert(m_pAbout);
+
+        set_default_size(Conf::get_window_width(), Conf::get_window_height());
+
+        show_all();
     }
 
+
     MainWindow::~MainWindow(void)
     {
         delete m_pAbout;
+        delete m_pHistory;
         //delete m_pHistory;
         LOG("MainWindow DELETED!");
     }
 
 
+    void MainWindow::on_realize()
+    {
+        Gtk::Window::on_realize();
+        // this can't be done in the constructor because get_width() doesn't
+        // return anything meaningful in the constructor
+        g_assert (m_pane);
+        m_pane->set_position(get_width() - Conf::get_favorites_width());
+    }
+
+
     // Actions must be initialized first
     void MainWindow::init_ui(void)
     {
@@ -240,12 +190,43 @@ namespace gcs
             throw ex;
         }
 
+        // cache some pointers to widgets from glade in class variables
+        m_vbox_layout = static_cast<Gtk::VBox*>(m_glade->get_widget("vbox_layout"));
+        g_assert(m_vbox_layout);
+        m_vbox_menu_toolbar = static_cast<Gtk::VBox*>(m_glade->get_widget("vbox_menu_toolbar"));
+        g_assert(m_vbox_menu_toolbar);
+        m_vbox_main = static_cast<Gtk::VBox*>(m_glade->get_widget("vbox_main"));
+        g_assert(m_vbox_main);
+        m_vbox_favorites = static_cast<Gtk::VBox*>(m_glade->get_widget("vbox_favorites"));
+        g_assert(m_vbox_favorites);
+        m_scrolledwindow_favorites = static_cast<Gtk::VBox*>(m_glade->get_widget("scrolledwindow_favorites"));
+        g_assert(m_scrolledwindow_favorites);
+        m_vbox_scheme_display = static_cast<Gtk::VBox*>(m_glade->get_widget("vbox_scheme_display"));
+        g_assert(m_vbox_scheme_display);
+        m_pane = static_cast<Gtk::HPaned*>(m_glade->get_widget("hpaned1"));
+        g_assert(m_pane);
+        m_main_menu = static_cast<Gtk::Menu *>(
+                m_refUIManager->get_widget("/MainMenu"));
+        g_assert(m_main_menu);
+        m_toolbar = static_cast<Gtk::Toolbar *>(
+                m_refUIManager->get_widget("/TweakBar"));
+        g_assert(m_toolbar);
+        m_color_button = static_cast<Gtk::ColorButton*>(m_glade->get_widget("colorbutton1"));
+        g_assert(m_color_button);
+        m_glade->get_widget_derived("combobox_scheme_selector", m_scheme_selector);
+        g_assert(m_scheme_selector);
+        m_glade->get_widget_derived("expander_palette", m_palette_view);
+        g_assert(m_palette_view);
+        m_bookmark_bar = dynamic_cast<Gtk::Toolbar *>(m_refUIManager->get_widget("/BookmarkBar"));
+        g_assert(m_bookmark_bar);
+        m_statusbar = static_cast<Gtk::Statusbar*>(m_glade->get_widget("statusbar1"));
+        g_assert(m_statusbar);
     }
 
 
     void MainWindow::set_color(ColorPtr c)
     {
-        m_pColorButton->set_color(c->gdk());
+        m_color_button->set_color(c->gdk());
         on_color_changed();
     }
 
@@ -253,7 +234,7 @@ namespace gcs
     void MainWindow::on_show(void)
     {
         Gtk::Window::on_show();
-        m_pSchemeSelector->set_scheme_type(Conf::get_last_scheme_type());
+        m_scheme_selector->set_scheme_type(Conf::get_last_scheme_type());
         // hack to get the schemetype selector to select the right starting
         // scheme
         on_schemetype_changed();
@@ -269,25 +250,28 @@ namespace gcs
         return true;
     }
 
+
     void MainWindow::quit(void)
     {
         hide();
-        ColorPtr clr = m_pSchemeBox->get_color();
+        ColorPtr clr = m_scheme_box->get_color();
         Conf::set_last_color(clr);
-        Conf::set_last_scheme_type(m_pSchemeBox->get_scheme_type());
+        Conf::set_last_scheme_type(m_scheme_box->get_scheme_type());
         // only save the window size if the window isn't maximized
         if (!(get_window()->get_state() & Gdk::WINDOW_STATE_MAXIMIZED))
         {
             Conf::set_window_width(get_width());
             Conf::set_window_height(get_height());
+            Conf::set_favorites_width(get_width() - m_pane->get_position());
+            Conf::set_palette_expanded(m_palette_view->get_expanded());
         }
     }
 
 
     void MainWindow::on_color_changed(void)
     {
-        ColorPtr clr = Color::create(m_pColorButton->get_color());
-        m_pSchemeBox->set_color(clr);
+        ColorPtr clr = Color::create(m_color_button->get_color());
+        m_scheme_box->set_color(clr);
         m_pHistory->add(clr->get_hexstring());
         //LOG(*m_pHistory);
         m_refActionGroup->get_action("HistoryBack")->set_sensitive(m_pHistory->has_back());
@@ -339,33 +323,27 @@ namespace gcs
             action->set_sensitive();
         }
         LOG("Color was changed!");
-        ColorPtr ptr = m_pBookmarkList->get_color();
+        ColorPtr ptr = m_bookmark_list->get_color();
         if (ptr && (*ptr != *clr))
         {
-            m_pBookmarkList->get_selection()->unselect_all();
+            m_bookmark_list->get_selection()->unselect_all();
         }
     }
 
 
     void MainWindow::on_schemetype_changed(void)
     {
-        tSchemeType type = m_pSchemeSelector->get_scheme_type();
-        m_pSchemeBox->set_scheme_type(type);
+        tSchemeType type = m_scheme_selector->get_scheme_type();
+        m_scheme_box->set_scheme_type(type);
 
         LOG("Scheme type is " << type);
     }
 
 
-    void MainWindow::on_menu_file_popup_generic(void)
-    {
-        std::cout << "mainwindow popup handler" << std::endl;
-    }
-
-
     void MainWindow::on_bookmarks_selection_changed(void)
     {
         LOG("Bookmarks changed");
-        ColorPtr pClr = m_pBookmarkList->get_color();
+        ColorPtr pClr = m_bookmark_list->get_color();
         if (pClr)
         {
             set_color(pClr);
