@@ -46,7 +46,7 @@ namespace gcs
         class BookmarkList : public Gtk::TreeView
         {
             public:
-                BookmarkList(Glib::ustring fname);
+                BookmarkList();
                 void add(ColorPtr clr);
                 void clear(void);
                 ColorPtr get_color(void);
