@@ -106,6 +106,16 @@ namespace gcs
                         iColor != m_pScheme->end(); iColor++, i++)
                 {
                     LOG("Swatch Color: " << *iColor);
+                    if (*iColor == m_pScheme->get_color())
+                    {
+                        // this is the color that the scheme is based on, so
+                        // let's emphasize it with a thicker border
+                        m_pSwatches[i]->set_border_width(3);
+                    }
+                    else
+                    {
+                        m_pSwatches[i]->set_border_width(1);
+                    }
                     // FIXME: is this ok?
                     m_pSwatches[i]->set_color(*iColor);
                     m_pSwatches[i]->show();
